@@ -108,6 +108,7 @@ import android.widget.SeekBar;
 import android.widget.SeekBar.OnSeekBarChangeListener;
 import android.widget.TextView;
 
+@TargetApi(Build.VERSION_CODES.JELLY_BEAN_MR1)
 public class VideoPlayerActivity extends Activity implements IVideoPlayer {
     public final static String TAG = "VLC/VideoPlayerActivity";
 
@@ -139,6 +140,7 @@ public class VideoPlayerActivity extends Activity implements IVideoPlayer {
     private View mOverlayHeader;
     private View mOverlayOption;
     private View mOverlayProgress;
+    private View mOverlayBackground;
     private static final int OVERLAY_TIMEOUT = 4000;
     private static final int OVERLAY_INFINITE = 3600000;
     private static final int FADE_OUT = 1;
@@ -267,6 +269,7 @@ public class VideoPlayerActivity extends Activity implements IVideoPlayer {
         mOverlayHeader = findViewById(R.id.player_overlay_header);
         mOverlayOption = findViewById(R.id.option_overlay);
         mOverlayProgress = findViewById(R.id.progress_overlay);
+        mOverlayBackground = findViewById(R.id.player_overlay_background);
 
         /* header */
         mTitle = (TextView) findViewById(R.id.player_overlay_title);
@@ -518,7 +521,7 @@ public class VideoPlayerActivity extends Activity implements IVideoPlayer {
     }
 
     private void startPlayback() {
-        load();
+        loadMedia();
 
         /*
          * if the activity has been paused by pressing the power button,
@@ -890,7 +893,7 @@ public class VideoPlayerActivity extends Activity implements IVideoPlayer {
             eventHandler.postDelayed(new Runnable() {
                 @Override
                 public void run() {
-                    load();
+                    loadMedia();
                 }
             }, 1000);
         } else {
@@ -930,7 +933,7 @@ public class VideoPlayerActivity extends Activity implements IVideoPlayer {
                 mPreviousHardwareAccelerationMode = mLibVLC.getHardwareAcceleration();
                 mLibVLC.setHardwareAcceleration(LibVLC.HW_ACCELERATION_DISABLED);
                 mSubtitlesSurface.setVisibility(View.INVISIBLE);
-                load();
+                loadMedia();
             }
         })
         .setNegativeButton(R.string.cancel, new DialogInterface.OnClickListener() {
@@ -942,7 +945,8 @@ public class VideoPlayerActivity extends Activity implements IVideoPlayer {
         .setTitle(R.string.hardware_acceleration_error_title)
         .setMessage(R.string.hardware_acceleration_error_message)
         .create();
-        dialog.show();
+        if(!isFinishing())
+            dialog.show();
     }
 
     private void handleVout(Message msg) {
@@ -1001,14 +1005,13 @@ public class VideoPlayerActivity extends Activity implements IVideoPlayer {
 
         // compute the aspect ratio
         double ar, vw;
-        double density = (double)mSarNum / (double)mSarDen;
-        if (density == 1.0) {
+        if (mSarDen == mSarNum) {
             /* No indication about the density, assuming 1:1 */
             vw = mVideoVisibleWidth;
             ar = (double)mVideoVisibleWidth / (double)mVideoVisibleHeight;
         } else {
             /* Use the specified aspect ratio */
-            vw = mVideoVisibleWidth * density;
+            vw = mVideoVisibleWidth * (double)mSarNum / mSarDen;
             ar = vw / mVideoVisibleHeight;
         }
 
@@ -1535,10 +1538,7 @@ public class VideoPlayerActivity extends Activity implements IVideoPlayer {
      * show overlay the the default timeout
      */
     private void showOverlay() {
-        if (mPresentation == null)
             showOverlay(OVERLAY_TIMEOUT);
-        else
-            showOverlay(OVERLAY_INFINITE); // Hack until we have fullscreen controls
     }
 
     /**
@@ -1556,6 +1556,7 @@ public class VideoPlayerActivity extends Activity implements IVideoPlayer {
                 dimStatusBar(false);
             }
             mOverlayProgress.setVisibility(View.VISIBLE);
+            if (mPresentation != null) mOverlayBackground.setVisibility(View.VISIBLE);
         }
         Message msg = mHandler.obtainMessage(FADE_OUT);
         if (timeout != 0) {
@@ -1570,9 +1571,6 @@ public class VideoPlayerActivity extends Activity implements IVideoPlayer {
      * hider overlay
      */
     private void hideOverlay(boolean fromUser) {
-        if (mPresentation != null)
-            return; // Hack until we have fullscreen controls
-
         if (mShowing) {
             mHandler.removeMessages(SHOW_PROGRESS);
             Log.i(TAG, "remove View!");
@@ -1583,6 +1581,10 @@ public class VideoPlayerActivity extends Activity implements IVideoPlayer {
                 mPlayPause.startAnimation(AnimationUtils.loadAnimation(this, android.R.anim.fade_out));
                 mMenu.startAnimation(AnimationUtils.loadAnimation(this, android.R.anim.fade_out));
             }
+            if (mPresentation != null) {
+                mOverlayBackground.startAnimation(AnimationUtils.loadAnimation(this, android.R.anim.fade_out));
+                mOverlayBackground.setVisibility(View.INVISIBLE);
+            }
             mOverlayHeader.setVisibility(View.INVISIBLE);
             mOverlayOption.setVisibility(View.INVISIBLE);
             mOverlayProgress.setVisibility(View.INVISIBLE);
@@ -1711,8 +1713,8 @@ public class VideoPlayerActivity extends Activity implements IVideoPlayer {
      * External extras:
      * - position (long) - position of the video to start with (in ms)
      */
-    @SuppressWarnings({ "deprecation", "unchecked" })
-    private void load() {
+    @SuppressWarnings({ "unchecked" })
+    private void loadMedia() {
         mLocation = null;
         String title = getResources().getString(R.string.title);
         boolean dontParse = false;
@@ -1723,43 +1725,64 @@ public class VideoPlayerActivity extends Activity implements IVideoPlayer {
 
         if (getIntent().getAction() != null
                 && getIntent().getAction().equals(Intent.ACTION_VIEW)) {
-            /* Started from external application */
+            /* Started from external application 'content' */
             if (getIntent().getData() != null
                     && getIntent().getData().getScheme() != null
                     && getIntent().getData().getScheme().equals("content")) {
-                if(getIntent().getData().getHost().equals("media") || getIntent().getData().getHost().equals("mms")) {
-                    // Media URI
-                    Cursor cursor = managedQuery(getIntent().getData(), new String[]{ MediaStore.Video.Media.DATA }, null, null, null);
-                    int column_index = cursor.getColumnIndexOrThrow(MediaStore.Video.Media.DATA);
-                    if (cursor.moveToFirst())
-                        mLocation = LibVLC.PathToURI(cursor.getString(column_index));
-                } else if(getIntent().getData().getHost().equals("com.fsck.k9.attachmentprovider")
-                       || getIntent().getData().getHost().equals("gmail-ls")) {
-                    // Mail-based apps - download the stream to a temporary file and play it
+
+                // Media or MMS URI
+                if(getIntent().getData().getHost().equals("media")
+                        || getIntent().getData().getHost().equals("mms")) {
                     try {
-                        Cursor cursor = getContentResolver().query(getIntent().getData(), new String[]{MediaStore.MediaColumns.DISPLAY_NAME}, null, null, null);
-                        cursor.moveToFirst();
-                        String filename = cursor.getString(cursor.getColumnIndex(MediaStore.MediaColumns.DISPLAY_NAME));
-                        Log.i(TAG, "Getting file " + filename + " from content:// URI");
-                        InputStream is = getContentResolver().openInputStream(getIntent().getData());
-                        OutputStream os = new FileOutputStream(Environment.getExternalStorageDirectory().getPath() + "/Download/" + filename);
-                        byte[] buffer = new byte[1024];
-                        int bytesRead = 0;
-                        while((bytesRead = is.read(buffer)) >= 0) {
-                            os.write(buffer, 0, bytesRead);
+                        Cursor cursor = getContentResolver().query(getIntent().getData(),
+                                new String[]{ MediaStore.Video.Media.DATA }, null, null, null);
+                        if (cursor != null) {
+                            int column_index = cursor.getColumnIndexOrThrow(MediaStore.Video.Media.DATA);
+                            if (cursor.moveToFirst())
+                                mLocation = LibVLC.PathToURI(cursor.getString(column_index));
+                            cursor.close();
+                        }
+                    } catch (Exception e) {
+                        Log.e(TAG, "Couldn't read the file from media or MMS");
+                        encounteredError();
+                    }
+                }
+
+                // Mail-based apps - download the stream to a temporary file and play it
+                else if(getIntent().getData().getHost().equals("com.fsck.k9.attachmentprovider")
+                       || getIntent().getData().getHost().equals("gmail-ls")) {
+                    try {
+                        Cursor cursor = getContentResolver().query(getIntent().getData(),
+                                new String[]{MediaStore.MediaColumns.DISPLAY_NAME}, null, null, null);
+                        if (cursor != null) {
+                            cursor.moveToFirst();
+                            String filename = cursor.getString(cursor.getColumnIndex(MediaStore.MediaColumns.DISPLAY_NAME));
+                            cursor.close();
+                            Log.i(TAG, "Getting file " + filename + " from content:// URI");
+
+                            InputStream is = getContentResolver().openInputStream(getIntent().getData());
+                            OutputStream os = new FileOutputStream(Environment.getExternalStorageDirectory().getPath() + "/Download/" + filename);
+                            byte[] buffer = new byte[1024];
+                            int bytesRead = 0;
+                            while((bytesRead = is.read(buffer)) >= 0) {
+                                os.write(buffer, 0, bytesRead);
+                            }
+                            os.close();
+                            is.close();
+                            mLocation = LibVLC.PathToURI(Environment.getExternalStorageDirectory().getPath() + "/Download/" + filename);
                         }
-                        os.close();
-                        is.close();
-                        mLocation = LibVLC.PathToURI(Environment.getExternalStorageDirectory().getPath() + "/Download/" + filename);
                     } catch (Exception e) {
                         Log.e(TAG, "Couldn't download file from mail URI");
                         encounteredError();
                     }
-                } else {
-                    // other content-based URI (probably file pickers)
+                }
+
+                // other content-based URI (probably file pickers)
+                else {
                     mLocation = getIntent().getData().getPath();
                 }
-            } else if (getIntent().getDataString() != null) {
+            } /* External application */
+            else if (getIntent().getDataString() != null) {
                 // Plain URI
                 mLocation = getIntent().getDataString();
                 // Remove VLC prefix if needed
@@ -1778,11 +1801,15 @@ public class VideoPlayerActivity extends Activity implements IVideoPlayer {
                 Log.e(TAG, "Couldn't understand the intent");
                 encounteredError();
             }
+
+            // Try to get the position
             if(getIntent().getExtras() != null)
                 intentPosition = getIntent().getExtras().getLong("position", -1);
-        } else if(getIntent().getAction() != null
-                && getIntent().getAction().equals(PLAY_FROM_VIDEOGRID) && getIntent().getExtras() != null) {
-            /* Started from VideoListActivity */
+        } /* ACTION_VIEW */
+        /* Started from VideoListActivity */
+        else if(getIntent().getAction() != null
+                && getIntent().getAction().equals(PLAY_FROM_VIDEOGRID)
+                && getIntent().getExtras() != null) {
             mLocation = getIntent().getExtras().getString("itemLocation");
             itemTitle = getIntent().getExtras().getString("itemTitle");
             dontParse = getIntent().getExtras().getBoolean("dontParse");
@@ -1843,6 +1870,7 @@ public class VideoPlayerActivity extends Activity implements IVideoPlayer {
                     mLibVLC.setTime(intentPosition);
             }
 
+            // Get possible subtitles
             String subtitleList_serialized = preferences.getString(PreferencesActivity.VIDEO_SUBTITLE_FILES, null);
             ArrayList<String> prefsList = new ArrayList<String>();
             if(subtitleList_serialized != null) {
@@ -1859,6 +1887,7 @@ public class VideoPlayerActivity extends Activity implements IVideoPlayer {
                     mSubtitleSelectedFiles.add(x);
              }
 
+            // Get the title
             try {
                 title = URLDecoder.decode(mLocation, "UTF-8");
             } catch (UnsupportedEncodingException e) {
