@@ -45,6 +45,9 @@ public class FlingViewGroup extends ViewGroup {
 
     private float mLastX;
     private float mLastInterceptDownY;
+    private float mInitialMotionX;
+    private float mInitialMotionY;
+
     private ViewSwitchListener mViewSwitchListener;
 
     public FlingViewGroup(Context context, AttributeSet attrs) {
@@ -79,8 +82,6 @@ public class FlingViewGroup extends ViewGroup {
     protected void onMeasure(int widthMeasureSpec, int heightMeasureSpec) {
         super.onMeasure(widthMeasureSpec, heightMeasureSpec);
 
-        final int width = MeasureSpec.getSize(widthMeasureSpec);
-
         final int widthMode = MeasureSpec.getMode(widthMeasureSpec);
 
         if (widthMode != MeasureSpec.EXACTLY ) {
@@ -88,11 +89,23 @@ public class FlingViewGroup extends ViewGroup {
         }
 
         final int count = getChildCount();
+        int maxHeight = 0;
         for (int i = 0; i < count; i++) {
-            getChildAt(i).measure(widthMeasureSpec, heightMeasureSpec);
+            View child = getChildAt(i);
+            child.measure(widthMeasureSpec, heightMeasureSpec);
+            maxHeight = Math.max(maxHeight, child.getMeasuredHeight());
         }
 
-        scrollTo(mCurrentView * width, 0);
+        setMeasuredDimension(getMeasuredWidth(), maxHeight);
+    }
+
+    @Override
+    protected void onSizeChanged(int w, int h, int oldw, int oldh) {
+        if (!mScroller.isFinished())
+            mScroller.abortAnimation();
+        super.onSizeChanged(w, h, oldw, oldh);
+        scrollTo(mCurrentView * w, 0);
+        requestLayout();
     }
 
     @Override
@@ -155,12 +168,17 @@ public class FlingViewGroup extends ViewGroup {
 
         final int action = event.getAction();
         final float x = event.getX();
+        final float y = event.getY();
 
         switch (action) {
             case MotionEvent.ACTION_DOWN:
+                mInitialMotionX = x;
+                mInitialMotionY = y;
                 if (!mScroller.isFinished())
                     mScroller.abortAnimation();
                 mLastX = x;
+                if (mViewSwitchListener != null)
+                    mViewSwitchListener.onTouchDown();
                 break;
             case MotionEvent.ACTION_MOVE:
                 int delta = (int) (mLastX - x);
@@ -198,6 +216,16 @@ public class FlingViewGroup extends ViewGroup {
                     mVelocityTracker = null;
                 }
 
+                if (mViewSwitchListener != null) {
+                    mViewSwitchListener.onTouchUp();
+                    final float dx = x - mInitialMotionX;
+                    final float dy = y - mInitialMotionY;
+                    ViewConfiguration config = ViewConfiguration.get(getContext());
+                    final int slop = config.getScaledTouchSlop();
+                    if (dx * dx + dy * dy < slop * slop)
+                        mViewSwitchListener.onTouchClick();
+                }
+
                 break;
         }
 
@@ -209,7 +237,10 @@ public class FlingViewGroup extends ViewGroup {
         super.onScrollChanged(l, t, oldl, oldt);
         if (mViewSwitchListener != null) {
             float progress = (float) l / (float) (getWidth() * (getChildCount() - 1));
-            mViewSwitchListener.onSwitching(progress);
+            if (l != mCurrentView * getWidth())
+                mViewSwitchListener.onSwitching(progress);
+            else
+                mViewSwitchListener.onSwitched(mCurrentView);
         }
     }
 
@@ -224,9 +255,20 @@ public class FlingViewGroup extends ViewGroup {
         final int delta = (position * getWidth()) - getScrollX();
         mScroller.startScroll(getScrollX(), 0, delta, 0, Math.abs(delta));
         invalidate();
-        if (mViewSwitchListener != null) {
-            mViewSwitchListener.onSwitched(position);
-        }
+    }
+
+    public void scrollTo(int position) {
+        mCurrentView = position;
+        final int delta = (position * getWidth()) - getScrollX();
+        mScroller.startScroll(getScrollX(), 0, delta, 0, 0);
+        invalidate();
+    }
+
+    public void smoothScrollTo(int position) {
+        mCurrentView = position;
+        final int delta = (position * getWidth()) - getScrollX();
+        mScroller.startScroll(getScrollX(), 0, delta, 0, 300);
+        invalidate();
     }
 
     public void setOnViewSwitchedListener(ViewSwitchListener l) {
@@ -237,6 +279,12 @@ public class FlingViewGroup extends ViewGroup {
         void onSwitching(float progress);
 
         void onSwitched(int position);
+
+        void onTouchDown();
+
+        void onTouchUp();
+
+        void onTouchClick();
     }
 
 }
